<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Essential is a clean and customizable theme.
 *
 * @package     theme_essential
 * @copyright   2018 Gareth J Barnard
 * @license     http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace theme_essential\privacy;

defined('MOODLE_INTERNAL') || die();

use \core_privacy\local\request\writer;
use \core_privacy\local\metadata\collection;

/**
 * The Essential theme can store user data if course search is on or ever has been on.
 */
class provider implements
    // This plugin has data.
    \core_privacy\local\metadata\provider,

    // This plugin has some sitewide user preferences to export.
    \core_privacy\local\request\user_preference_provider {

    /**
     * Returns meta data about this system.
     *
     * @param   collection $itemcollection The initialised item collection to add items to.
     * @return  collection A listing of user data stored through this system.
     */
    public static function get_metadata(collection $items) {
        $items->add_user_preference('theme_essential_courseitemsearchtype', 'privacy:metadata:preference:courseitemsearchtype');
        return $items;
    }

    /**
     * Store all user preferences for the plugin.
     *
     * @param int $userid The userid of the user whose data is to be exported.
     */
    public static function export_user_preferences($userid) {
        $courseitemsearchtype = get_user_preferences('theme_essential_courseitemsearchtype', null, $userid);

        if (!is_null($courseitemsearchtype)) {
            writer::export_user_preference(
                'theme_essential',
                'theme_essential_courseitemsearchtype',
                $courseitemsearchtype,
                get_string('privacy:request:preference:courseitemsearchtype', 'theme_essential', (object) [
                    'name' => 'theme_essential_courseitemsearchtype',
                    'value' => $courseitemsearchtype
                ])
            );
        }
    }
}
